*************
aas-core-meta
*************

.. image:: https://github.com/aas-core-works/aas-core-meta/workflows/CI/badge.svg
    :target: https://github.com/aas-core-works/aas-core-meta/actions?query=workflow%3ACI
    :alt: Continuous integration

.. image:: https://badge.fury.io/py/aas-core-meta.svg
    :target: https://badge.fury.io/py/aas-core-meta
    :alt: PyPI - version

.. image:: https://img.shields.io/pypi/pyversions/aas-core-meta.svg
    :alt: PyPI - Python Version


We provide here meta-models for asset administration shell information model written in simplified Python.

For more information and a more abstract overview, please see our design documents: https://aas-core-works.github.io/design-docs/

Contributors
============
* Nico Braunisch
* Marko Ristin
* Robert Lehmann
* Marcin Sadurski
* Manuel Sauer
* Sebastian Bader

Contributing
============

Feature requests or bug reports are always very, very welcome!

Please see quickly if the issue does not already exist in the `issue section`_ and,
if not, create `a new issue`_.

.. _issue section: https://github.com/aas-core-works/aas-core-meta/issues
.. _a new issue: https://github.com/aas-core-works/aas-core-meta/issues/new

You can also contribute in code.
Please see `CONTRIBUTING.rst`_.

.. _CONTRIBUTING.rst: https://github.com/aas-core-works/aas-core-meta/blob/main/CONTRIBUTING.rst

Versioning
==========
Since this package keeps track of multiple versions of the meta-model, we opt to release following a simple release date schema.

For example, for a release on November 20th 2021, we use the version: ``2021.11.20``.
